package com.muyu.auth.controller;

import com.muyu.auth.form.EnterpriseSettlement;
import com.muyu.auth.form.Firm;
import com.muyu.auth.form.LoginBody;
import com.muyu.auth.form.RegisterBody;
import com.muyu.auth.service.SysFirmService;
import com.muyu.auth.service.SysLoginService;
import com.muyu.cloud.common.many.datasource.constents.DatasourceContent;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.JwtUtils;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.security.auth.AuthUtil;
import com.muyu.common.security.service.TokenService;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.common.system.domain.LoginUser;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.support.EncodedResource;
import org.springframework.jdbc.datasource.init.ScriptUtils;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import jakarta.servlet.http.HttpServletRequest;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;

/**
 * token 控制
 *
 * @author muyu
 */
@Log4j2
@RestController
public class TokenController {
    @Autowired
    private TokenService tokenService;

    @Autowired
    private SysLoginService sysLoginService;

    @Autowired
    private SysFirmService sysFirmService;

    @PostMapping("login")
    public Result<?> login (@RequestBody LoginBody form) {
        //查询企业是否存在
        Firm firm = sysFirmService.findFirmByName(form.getFirmName());
        if (firm.getDatabaseName() == null){
            return Result.error(null,"企业不存在");
        }
        // 用户登录
        LoginUser userInfo = sysLoginService.login(form.getUsername(), form.getPassword());
        // 获取登录token
        return Result.success(tokenService.createToken(userInfo));
    }

    @DeleteMapping("logout")
    public Result<?> logout (HttpServletRequest request) {
        String token = SecurityUtils.getToken(request);
        if (StringUtils.isNotEmpty(token)) {
            String username = JwtUtils.getUserName(token);
            // 删除用户缓存记录
            AuthUtil.logoutByToken(token);
            // 记录用户退出日志
            sysLoginService.logout(username);
        }
        return Result.success();
    }

    @PostMapping("refresh")
    public Result<?> refresh (HttpServletRequest request) {
        LoginUser loginUser = tokenService.getLoginUser(request);
        if (StringUtils.isNotNull(loginUser)) {
            // 刷新令牌有效期
            tokenService.refreshToken(loginUser);
            return Result.success();
        }
        return Result.success();
    }

    @PostMapping("register")
    public Result<?> register (@RequestBody RegisterBody registerBody) {
        // 用户注册
        sysLoginService.register(registerBody.getUsername(), registerBody.getPassword());
        return Result.success();
    }

    /**
     * 企业入入驻
     * @param settlement
     * @return
     */
    @PostMapping("/enterprise")
    public Result<?> enterprise( @RequestBody EnterpriseSettlement settlement){

        String createDatabaseUrl="jdbc:mysql://"+ DatasourceContent.IP+":"+DatasourceContent.PORT+"?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8";
        String createDatabaseSql = "CREATE DATABASE IF NOT EXISTS " + settlement.getDatabaseName() + ";";
        try (Connection adminConn = DriverManager.getConnection(createDatabaseUrl, DatasourceContent.USER_NAME, DatasourceContent.PASSWORD);
             Statement stmt = adminConn.createStatement()) {

            boolean success = stmt.execute(createDatabaseSql);
            if (success) {
                log.info("数据库 {} 创建失败", settlement.getDatabaseName());

            } else {
                log.warn("数据库 {} 创建成功", settlement.getDatabaseName());

                // 切换到新的数据库连接
                Connection connection = null;
                try {
                    String url = "jdbc:mysql://47.101.53.251:3306/" + settlement.getDatabaseName() + "?useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8";
                    String user = "root";
                    String pwd = "Lw030106";
                    String driverClassName = "com.mysql.cj.jdbc.Driver";
                    Class.forName(driverClassName);
                    connection = DriverManager.getConnection(url, user, pwd);
                } catch (ClassNotFoundException e) {
                    throw new RuntimeException(e);
                }
                ClassPathResource rc = new ClassPathResource("static/saas.sql");
                EncodedResource er = new EncodedResource(rc, "utf-8");
                ScriptUtils.executeSqlScript(connection, er);
            }

        } catch (SQLException e) {
            e.printStackTrace();
            log.error("连接数据库时发生错误或创建数据库失败", e);
        }
        //企业入驻
        sysLoginService.enterprise(settlement.getDatabaseName(),settlement.getFirmName());

        return Result.success();
    }
}
