package com.muyu.common.kafka.config;



import com.muyu.common.core.constant.KafkaConstant;
import org.apache.kafka.clients.consumer.KafkaConsumer;
import org.apache.kafka.common.serialization.StringDeserializer;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.HashMap;
import java.util.Map;

/**
* kafka消费者配置类
* @program: cloud-server
* @author: cuiyongxing
* @create: 2024-09-28 14:28
**/
@Configuration
public class KafkaConsumerConfig {

    /**
     * 服务端id+端口号
     */
    @Value("${spring.kafka.consumer.bootstrap-servers}")
    private String bootstrapServers;

    /**
     * 偏移量
     */
    @Value("${spring.kafka.consumer.enable-auto-commit}")
    private Boolean enableAutoCommit;

    /**
     * 自动提交时间间隔
     */
    @Value("${spring.kafka.consumer.auto-commit-interval}")
    private Integer autoCommitInterval;

    /**
     * 偏移量配置
     */
    @Value("${spring.kafka.consumer.auto-offset-reset}")
    private String autoOffsetReset;

    /**
     * 阻塞最大时间
     */
    @Value("${spring.kafka.consumer.fetch-max-wait}")
    private Integer fetchMaxWait;

    /**
     * 请求最小字节
     */
    @Value("${spring.kafka.consumer.fetch-min-size}")
    private Integer fetchMinSize;

    /**
     * 心跳间隔时间
     */
    @Value("${spring.kafka.consumer.heartbeat-interval}")
    private Integer heartbeatInterval;

    /**
     * 最大记录条数
     */
    @Value("${spring.kafka.consumer.max-poll-records}")
    private Integer maxPollRecords;

    /**
     * 消费组
     */
    @Value("${spring.kafka.consumer.group-id}")
    private String groupId;


    @Bean
    public KafkaConsumer kafkaConsumer(){
        Map<String,Object> configs = new HashMap<>();
        configs.put(KafkaConstant.BOOTSTRAP_SERVERS, bootstrapServers);
        configs.put(KafkaConstant.ENABLE_AUTO_COMMIT, enableAutoCommit);
        configs.put(KafkaConstant.AUTO_COMMIT_INTERVAL, autoCommitInterval);
        configs.put(KafkaConstant.AUTO_OFFSET_RESET, autoOffsetReset);
        configs.put(KafkaConstant.FETCH_MAX_WAIT, fetchMaxWait);
        configs.put(KafkaConstant.FETCH_MIN_SIZE, fetchMinSize);
        configs.put(KafkaConstant.HEARTBEAT_INTERVAL, heartbeatInterval);
        configs.put(KafkaConstant.MAX_POLL_RECORDS, maxPollRecords);
        configs.put(KafkaConstant.GROUP_ID, groupId);
        StringDeserializer keyDeserializer = new StringDeserializer();
        StringDeserializer valueDeserializer = new StringDeserializer();
        return new KafkaConsumer(configs, keyDeserializer, valueDeserializer);
    }

}
