package com.muyu.common.kafka.config;

import com.muyu.common.core.constant.KafkaConstant;
import org.apache.kafka.clients.producer.KafkaProducer;
import org.apache.kafka.common.serialization.StringSerializer;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;


import java.util.HashMap;
import java.util.Map;

/**
 * kafka生产者配置信息
 * @program: cloud-server
 * @author: cuiyongxing
 * @create: 2024-09-28 12:03
 **/
@Configuration
public class KafkaProducerConfig {

    /**
     * 服务端ip+端口号
     */
    @Value("${spring.kafka.producer.bootstrap-servers}")
    private String bootstrapServers;
    /**
     * 重试次数
     */
    @Value("${spring.kafka.producer.retries}")
    private Integer retries;

    /**
     * 默认批量大小
     */
    @Value("${spring.kafka.producer.batch-size}")
    private Integer batchSize;
    /**
     * 总内存字节数
     */
    @Value("${spring.kafka.producer.buffer-memory}")
    private Integer bufferMemory;

    /**
     * 偏移量
     */
    @Value("${spring.kafka.producer.acks}")
    private String acks;




    @Bean
    public KafkaProducer kafkaProducer() {
        Map<String, Object> configs = new HashMap<>();
        configs.put(KafkaConstant.BOOTSTRAP_SERVERS, bootstrapServers);
        configs.put(KafkaConstant.RETRIES, retries);
        configs.put(KafkaConstant.BATCH_SIZE, batchSize);
        configs.put(KafkaConstant.BUFFER_MEMORY, bufferMemory);
        configs.put(KafkaConstant.ACKS, acks);
        StringSerializer keySerializer = new StringSerializer();
        StringSerializer valueSerializer = new StringSerializer();
        KafkaProducer kafkaProducer = new KafkaProducer<>(configs, keySerializer, valueSerializer);
        return kafkaProducer;
    }

}
