package com.muyu.common.rabbit.config;


import com.muyu.common.rabbit.constants.RabbitmqConstants;
import org.springframework.amqp.core.*;
import org.springframework.amqp.rabbit.core.RabbitAdmin;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.annotation.Resource;
import java.util.HashMap;

/**
 * @ClassName: DelayedQueueConfig
 * @Description: 延迟队列配置类
 */
@Configuration
public class DelayedQueueConfig {


    @Resource
    private RabbitAdmin rabbitAdmin;

    /**
     * 声明队列
     * @return 返回队列
     */
    @Bean
    public Queue delayedQueue() {
        Queue queue = new Queue(RabbitmqConstants.DELAYED_QUEUE_NAME);
        rabbitAdmin.declareQueue(queue);
        return queue;
    }

    /**
     * 声明交换机
     * @return 返回交换机
     */
    @Bean
    public Exchange delayedExchange() {
        HashMap<String, Object> arguments = new HashMap<>(3);

        arguments.put("x-delayed-type", "direct");

        /**
         * 声明自定义交换机
         * 第一个参数：交换机的名称
         * 第二个参数：交换机的类型
         * 第三个参数：是否需要持久化
         * 第四个参数：是否自动删除
         * 第五个参数：其他参数
         */
        CustomExchange customExchange = new CustomExchange(
                RabbitmqConstants.DELAYED_EXCHANGE_NAME,
                "x-delayed-message",
                true,
                false,
                arguments);
        rabbitAdmin.declareExchange(customExchange);
        return customExchange;
    }

    /**
     * 绑定交换机
     * @param delayedQueue 队列对象
     * @param delayedExchange 交换机对象
     */
    @Bean
    public Binding delayedQueueBindingDelayedExchange(
            @Qualifier("delayedQueue") Queue delayedQueue,
            @Qualifier("delayedExchange") Exchange delayedExchange) {

        Binding noargs = BindingBuilder.bind(delayedQueue)
                .to(delayedExchange)
                .with(RabbitmqConstants.DELAYED_ROUTING_KEY)
                .noargs();
        rabbitAdmin.declareBinding(noargs);
        return noargs;
    }


}
