package com.muyu.common.rabbit.consumer;

import com.alibaba.fastjson2.JSONObject;
import com.muyu.common.redis.service.RedisService;
import com.rabbitmq.client.Channel;
import lombok.AllArgsConstructor;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.core.Message;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.Date;

/**
 * @ClassName: RabbitMQConsumerUtil
 * @Description: rabbitmq消费者
 */
@Component
@Log4j2
@AllArgsConstructor
public class RabbitMQConsumerUtil {

    private final RedisService redisService;


    /**
     * 普通消费者
     * @param data 数据类型
     * @param message
     * @param channel
     */
    public void rabbitMQBasicConsumer(Object data ,Message message , Channel channel) {
        log.info("当前时间：{} ：RabbitMQConsumerUtil : {}", new Date(), message);
        try {
            // 获取到消息 开始消费
            log.info("消息消费者接收到消息，消息内容：{}", JSONObject.toJSONString(data));

            Long add = redisService.redisTemplate.opsForSet().add(data, message.getMessageProperties().getMessageId());

            if (add != 1) {
                return;
            }
            // 消费消息成功之后需要确认
            // long deliveryTag  消息投递序号  自增的数字  在整个队列中唯一 拿到这个序号就相当于拿到这条消息
            // boolean multiple  是否批量确认  true 批量  确认小于等于当前投递序号的消息   false 单个确认
            channel.basicAck(message.getMessageProperties().getDeliveryTag(), false);
            log.info("xxx消费者接收到消息，消息内容：{}，消费成功...", message);

        } catch (Exception e) {
            log.error("xxx消费者接收到消息，消息内容：{}，消费消息异常，异常信息：{}", message, e);
            // 消息回退  拒绝消费消息
            // long deliveryTag  消息投递序号  自增的数字  在整个队列中唯一 拿到这个序号就相当于拿到这条消息
            // boolean requeue   是否回到原来的队列
            try {
                channel.basicReject(message.getMessageProperties().getDeliveryTag(), true);
//                channel.basicNack(message.getMessageProperties().getDeliveryTag(), false, true);
            } catch (IOException ex) {
                log.error("xxx消费者接收到消息，消息内容：{}，回退消息异常，异常信息：{}", message, ex);
            }
        }finally {
            try {
                channel.close();
            } catch (Exception e) {
                log.error("xxx消费者关闭Channel异常，消息内容：{}，异常信息：{}", message, e);
            }
        }
    }

    /**
     * 普通消费者
     * @param data 数据类型
     * @param message
     * @param channel
     */
    public void carUpConsumer(String data,Message message , Channel channel) {
        log.info("当前时间：{} ：RabbitMQConsumerUtil : {}", new Date(), message);
        try {
            // 获取到消息 开始消费
            log.info("消息消费者接收到消息，消息内容：{}", JSONObject.toJSONString(data));


            Long add = redisService.redisTemplate.opsForSet().add(data, message.getMessageProperties().getMessageId());

            if (add != 1) {
                return;
            }

            /**
             * -----------------------------------以下为异步业务操作----------------------------
             */
            log.info("[ 根据vin拿到缓存 ] vin为 --》 {}",data);
            log.info("[ 存入本地缓存 ] 数据为 --》 {}",data);
            log.info("[ 存入本地缓存 ] 数据为 --》 {}",data);
            /**
             * ------------------------------------------------------------------------------
             */
            // 消费消息成功之后需要确认
            // long deliveryTag  消息投递序号  自增的数字  在整个队列中唯一 拿到这个序号就相当于拿到这条消息
            // boolean multiple  是否批量确认  true 批量  确认小于等于当前投递序号的消息   false 单个确认
            channel.basicAck(message.getMessageProperties().getDeliveryTag(), false);
            log.info("xxx消费者接收到消息，消息内容：{}，消费成功...", message);

        } catch (Exception e) {
            log.error("xxx消费者接收到消息，消息内容：{}，消费消息异常，异常信息：{}", message, e);
            // 消息回退  拒绝消费消息
            // long deliveryTag  消息投递序号  自增的数字  在整个队列中唯一 拿到这个序号就相当于拿到这条消息
            // boolean requeue   是否回到原来的队列
            try {
                channel.basicReject(message.getMessageProperties().getDeliveryTag(), true);
//                channel.basicNack(message.getMessageProperties().getDeliveryTag(), false, true);
            } catch (IOException ex) {
                log.error("xxx消费者接收到消息，消息内容：{}，回退消息异常，异常信息：{}", message, ex);
            }
        }finally {
            try {
                channel.close();
            } catch (Exception e) {
                log.error("xxx消费者关闭Channel异常，消息内容：{}，异常信息：{}", message, e);
            }
        }
    }






}
