package com.muyu.event.util;

import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;
import org.springframework.stereotype.Component;

/**
 * 缓存工具类
 *
 * @program: cloud-server
 * @author: 刘武
 * @create: 2024-09-30 10:08
 **/
@Component
public class CacheUtil<T> {

    private final Cache<String, T> cache;

    public CacheUtil() {
        this.cache = Caffeine.newBuilder()
                .maximumSize(500L)
                .build();
    }

    public T get(String key) {
        return cache.getIfPresent(key);
    }

    public void put(String key, T value) {
        cache.put(key, value);
    }

    public void remove(String key) {
        cache.invalidate(key);
    }

}
