package com.muyu.vehicle.config;
import com.aliyun.ecs20140526.Client;
import com.aliyun.ecs20140526.models.DeleteInstancesRequest;
import com.aliyun.ecs20140526.models.DescribeInstancesRequest;
import com.aliyun.ecs20140526.models.DescribeInstancesResponse;
import com.aliyun.ecs20140526.models.DescribeInstancesResponseBody;
import com.aliyun.tea.TeaException;
import com.aliyun.teaopenapi.models.Config;
import com.aliyun.teautil.Common;
import com.aliyun.teautil.models.RuntimeOptions;
import com.muyu.vehicle.utils.CreateClient;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.stereotype.Component;

import java.util.ArrayList;

/**
 * 删除实例信息
 */
@Component
@Log4j2
public class CloseInstance implements DisposableBean{

    /**
     * <b>description</b> :
     * <p>使用AK&amp;SK初始化账号Client</p>
     * @return Client
     *
     * @throws Exception
     */
    public static void delInstance() throws Exception {

        // 创建ECS客户端对象，用于后续调用ECS相关API
        Client client = CreateClient.createClient();

        DescribeInstancesRequest describeInstancesRequest = new DescribeInstancesRequest()
                .setRegionId("cn-shanghai");

        //创建运行时选择对象,用于配置运行时的选项参数
        RuntimeOptions runtimeOptions = new RuntimeOptions();

        //获取实例列表
        DescribeInstancesResponse describeInstancesResponse = client.describeInstancesWithOptions(describeInstancesRequest, runtimeOptions);

        //提取实例ID集合
        ArrayList<String> list = new ArrayList<>();
        DescribeInstancesResponseBody body = describeInstancesResponse.getBody();

        for (DescribeInstancesResponseBody.DescribeInstancesResponseBodyInstancesInstance instance : body.getInstances().getInstance()) {
            if (!instance.getInstanceId().equals("i-uf68jwsbbqq4b4xc893s")) {
                list.add(instance.getInstanceId());
            }
        }
        log.info("搜索到实例Instance IDs: " + list);
        // 创建删除实例请求对象，并设置请求参数
        DeleteInstancesRequest deleteInstancesRequest = new DeleteInstancesRequest()
                // 设置地域ID，指定删除实例的地域
                .setRegionId("cn-shanghai")
                // 设置DryRun为true，用于验证请求是否可以成功，但不实际执行删除操作
                .setDryRun(false)
                // 设置Force为true，表示即使实例有正在运行的任务，也强制删除实例
                .setForce(true)
                // 设置TerminateSubscription为true，表示删除按订阅付费的实例时终止订阅
                .setTerminateSubscription(true)
                .setInstanceId(list);

        // 创建运行时选项对象，用于配置运行时的选项参数
        RuntimeOptions runtime = new RuntimeOptions();
        try {
            // 复制代码运行请自行打印 API 的返回值
            client.deleteInstancesWithOptions(deleteInstancesRequest, runtime);
        } catch (TeaException error) {
            // 此处仅做打印展示，请谨慎对待异常处理，在工程项目中切勿直接忽略异常。
            // 错误 message
            log.info(error.getMessage());
            // 诊断地址
            log.info(error.getData().get("Recommend"));
            Common.assertAsString(error.message);
        } catch (Exception _error) {
            TeaException error = new TeaException(_error.getMessage(), _error);
            // 此处仅做打印展示，请谨慎对待异常处理，在工程项目中切勿直接忽略异常。
            // 错误 message
            System.out.println(error.getMessage());
            // 诊断地址
            log.info(error.getData().get("Recommend"));
            Common.assertAsString(error.message);
        }
    }


    @Override
    public void destroy() throws Exception {
        log.info("开始删除实例");
        delInstance();
    }
}


