package com.muyu.vehicle.config;

import com.alibaba.fastjson.JSON;
import com.aliyun.ecs20140526.Client;
import com.aliyun.ecs20140526.models.DescribeInstancesRequest;
import com.aliyun.ecs20140526.models.DescribeInstancesResponse;
import com.aliyun.ecs20140526.models.DescribeInstancesResponseBody;
import com.aliyun.teautil.Common;
import com.aliyun.teautil.models.RuntimeOptions;
import com.muyu.vehicle.domain.InstanceInfo;
import com.muyu.vehicle.utils.CreateClient;
import lombok.extern.log4j.Log4j2;

import java.util.ArrayList;
import java.util.List;

/**
 * 查询实例信息
 */

@Log4j2
public class SelectInstance {
    public static List<InstanceInfo> selectInstance(List<String> instanceIds) throws Exception {
        // 创建ECS客户端对象，用于后续调用ECS相关API
        Client client = CreateClient.createClient();
        ArrayList<InstanceInfo> instanceInfos = new ArrayList<>();// 实例基础信息
        com.aliyun.ecs20140526.models.DescribeInstancesRequest describeInstancesRequest = new com.aliyun.ecs20140526.models.DescribeInstancesRequest()
                .setInstanceIds(JSON.toJSONString(instanceIds))
                .setRegionId("cn-shanghai");
        // 创建运行时选项对象
        RuntimeOptions runtime = new RuntimeOptions();
        //实例ID Instances.Instance.InstanceId
        //实例IP Instances.Instance.PublicIpAddress.IpAddress
        //状态 Instances.Instance.Status
        DescribeInstancesResponse resp = client.describeInstancesWithOptions(describeInstancesRequest, runtime);
        DescribeInstancesResponseBody body = resp.getBody();

        ArrayList<InstanceInfo> list = new ArrayList<>();
        for (DescribeInstancesResponseBody.DescribeInstancesResponseBodyInstancesInstance instance : body.getInstances().getInstance()){
            InstanceInfo instanceInfo = new InstanceInfo();
            instanceInfo.setInstanceId(instance.getInstanceId());
            log.info("实例ID:{}",instanceInfo.getInstanceId());
            instanceInfo.setStatus(instance.getStatus());
            log.info("实例状态:{}",instanceInfo.getStatus());
            instanceInfo.setIpAddress(String.valueOf(instance.getPublicIpAddress().getIpAddress()));
            log.info("实例IP:{}",instanceInfo.getIpAddress());
            list.add(instanceInfo);
        }
        log.info("实例信息:",list);
        return instanceInfos;
    }

}
