package com.muyu.server.controller;

import com.muyu.cache.TemplateCacheService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.domain.Template;
import com.muyu.server.service.TemplateService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.extern.log4j.Log4j2;
import org.apache.iotdb.rpc.IoTDBConnectionException;
import org.apache.iotdb.rpc.StatementExecutionException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.sql.SQLException;
import java.util.List;
import java.util.concurrent.ExecutionException;

/**
 * 报文模版管理
 * @author liuxinyue
 * @Package：com.template.controller
 * @Project：cloud-server-c
 * @name：TemplateController
 * @Date：2024/9/20 12:12
 */
@Log4j2
@RestController
@RequestMapping("/template")
@AllArgsConstructor
@Tag(name = "报文模版管理",description = "报文模版管理")
public class TemplateController {

    @Autowired
    private TemplateService templateService;

    @Autowired
    private TemplateCacheService templateCacheService;

    /**
     * 报文模版列表
     * @return
     */
    @PostMapping("/templateList")
    @Operation(summary = "报文模版列表",description = "报文模版列表")
    public Result<List<Template>> templateList() {

        List<Template> list = templateService.list();

        templateCacheService.put("List",list);

        return Result.success(list);
    }




    /**
     * 报文模版添加
     * @param template
     * @return
     */
    @PostMapping("/addTemplate")
    @Operation(summary = "报文模版添加",description = "报文模版添加")
    public Result addTemplate(@RequestBody Template template) {
        boolean save = templateService.save(template);
        log.info("添加的结果为:"+save);
        return Result.success();
    }


}
