package com.muyu.server.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.cache.WarnRuleCacheService;
import com.muyu.common.domain.WarnRule;
import com.muyu.common.domain.resp.WarnRuleResp;
import com.muyu.server.mapper.WarnRuleMapper;
import com.muyu.server.service.WarnRuleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

import java.util.List;

/**
 * 预警规则Service业务层处理
 *
 * @author muyu
 * @date 2024-09-20
 */
@Service
public class WarnRuleServiceImpl
        extends ServiceImpl<WarnRuleMapper, WarnRule>
        implements WarnRuleService {
    @Autowired
    private WarnRuleMapper warnRuleMapper;

    @Autowired
    private WarnRuleCacheService warnRuleCacheService;

    /**
     * 精确查询预警规则
     *
     * @param id 预警规则主键
     * @return 预警规则
     */
    @Override
    public WarnRule selectWarnRuleById(Long id)
    {
        WarnRule warnRule = warnRuleMapper.selectById(id);
        return warnRule;
    }


    /**
     * 查询预警规则列表
     *
     * @param
     * @return 预警规则
     */
    @Override
    public List<WarnRuleResp> selectWarnRuleRespList()
    {
        List<WarnRuleResp> warnRuleResps = warnRuleMapper.selectWarnRuleRespList();
        warnRuleCacheService.put("List",warnRuleResps);
        return warnRuleResps;
    }

    @Override
    public Integer addWarnRule(WarnRule warnRule) {
        int rows = warnRuleMapper.insert(warnRule);
        return rows;
    }

    @Override
    public Integer updWarnRule(WarnRule warnRule) {
        LambdaQueryWrapper<WarnRule> queryWrapper = new LambdaQueryWrapper<>();
        Integer update = warnRuleMapper.update(queryWrapper);
        return update;
    }

    @Override
    public List<WarnRuleResp> selectListByStrategyId(Long strategyId) {
        List<WarnRuleResp> warnRuleResps = warnRuleMapper.selectListByStrategyId(strategyId);
        return warnRuleResps;
    }


}
